package com.test.service.service;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.IBinder;
import android.os.RemoteException;
import android.content.BroadcastReceiver;
import android.bluetooth.BluetoothAdapter;

import com.test.service.IMyAidlInterface;

public class MyService extends Service {
    private ServiceBinder mBinder = new ServiceBinder();
    protected int isBound = 0;

    @Override
    public void onCreate() {
        super.onCreate();
        isBound = 0;

        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(BluetoothAdapter.ACTION_STATE_CHANGED);
        this.registerReceiver(NotificationBroadcastReceiver, intentFilter);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        this.unregisterReceiver(NotificationBroadcastReceiver);
        isBound = 0;
    }

    @Override
    public int onStartCommand(final Intent intent, final int flags, final int startId) {
        //return super.onStartCommand(intent, flags, startId);
        // The service does not save addresses of managed devices.
        // A bound activity will be required to add connections again.
        return START_STICKY;
    }

    @Override
    public IBinder onBind(Intent intent) {
        // TODO: Return the communication channel to the service.

        return mBinder;
    }


    public final BroadcastReceiver NotificationBroadcastReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(final Context context, final Intent intent) {
            String action = intent.getAction();

            if (BluetoothAdapter.ACTION_STATE_CHANGED.equals(action)) {
                final int state = intent.getIntExtra(BluetoothAdapter.EXTRA_STATE, BluetoothAdapter.STATE_OFF);
                final int previousState = intent.getIntExtra(BluetoothAdapter.EXTRA_PREVIOUS_STATE, BluetoothAdapter.STATE_OFF);

                switch (state) {
                    case BluetoothAdapter.STATE_ON:
                        // On older phones (tested on Nexus 4 with Android 5.0.1) the Bluetooth requires some time
                        // after it has been enabled before some operations can start. Starting the GATT server here
                        // without a delay is very likely to cause a DeadObjectException from BluetoothManager#openGattServer(...).
                        break;

                    case BluetoothAdapter.STATE_TURNING_OFF:
                    case BluetoothAdapter.STATE_OFF:

                        break;
                }
            }
        }
    };

    public class ServiceBinder extends IMyAidlInterface.Stub{
        @Override
        public String getMessage() throws RemoteException {
            return "Remote Service bind is ok";
        }
    };
}
